@@ -622,7 +622,8 @@ int ssl_hook_Handler(request_rec *r)
         if (!ap_is_default_port(port, r))
             thisport = ap_psprintf(r->pool, ":%u", port);
         thisurl = ap_psprintf(r->pool, "https://%s%s/",
-                              ap_get_server_name(r), thisport);
+                              ap_escape_html(r->pool, ap_get_server_name(r)),
+			      thisport);
 
         ap_table_setn(r->notes, "error-notes", ap_psprintf(r->pool,
                       "Reason: You're speaking plain HTTP to an SSL-enabled server port.<BR>\n"
@@ -1582,6 +1583,7 @@ int ssl_callback_SSLVerify_CRL(
     int i, n, rc;
     char *cp;
     char *cp2;
+    ASN1_TIME *t;
 
     /*
      * Unless a revocation store for CRLs was created we
@@ -1671,14 +1673,13 @@ int ssl_callback_SSLVerify_CRL(
         /*
          * Check date of CRL to make sure it's not expired
          */
-        i = X509_cmp_current_time(X509_CRL_get_nextUpdate(crl));
-        if (i == 0) {
+        if ((t = X509_CRL_get_nextUpdate(crl)) == NULL) {
             ssl_log(s, SSL_LOG_WARN, "Found CRL has invalid nextUpdate field");
             X509_STORE_CTX_set_error(ctx, X509_V_ERR_ERROR_IN_CRL_NEXT_UPDATE_FIELD);
             X509_OBJECT_free_contents(&obj);
             return FALSE;
         }
-        if (i < 0) {
+        if (X509_cmp_current_time(t) < 0) {
             ssl_log(s, SSL_LOG_WARN,
                     "Found CRL is expired - "
                     "revoking all certificates until you get updated CRL");
